@@ -318,7 +318,7 @@ pango_fc_font_face_data_free (PangoFcFontFaceData *data)
   FcPatternDestroy (data->pattern);
 
   if (data->coverage)
-    pango_coverage_unref (data->coverage);
+    g_object_unref (data->coverage);
 
   g_free (data->languages);
 
@@ -835,7 +835,9 @@ match_in_thread (gpointer task_data)
   ThreadData *td = task_data;
   FcResult result;
   FcPattern *match;
-  gint64 before = PANGO_TRACE_CURRENT_TIME;
+  gint64 before G_GNUC_UNUSED;
+
+  before = PANGO_TRACE_CURRENT_TIME;
 
   match = FcFontSetMatch (td->config,
                           &td->fonts, 1,
@@ -860,7 +862,9 @@ sort_in_thread (gpointer task_data)
   ThreadData *td = task_data;
   FcResult result;
   FcFontSet *fontset;
-  gint64 before = PANGO_TRACE_CURRENT_TIME;
+  gint64 before G_GNUC_UNUSED;
+
+  before = PANGO_TRACE_CURRENT_TIME;
 
   fontset = FcFontSetSort (td->config,
                            &td->fonts, 1,
@@ -1023,9 +1027,11 @@ pango_fc_patterns_get_font_pattern (PangoFcPatterns *pats, int i, gboolean *prep
 
   if (i == 0)
     {
-      gint64 before = PANGO_TRACE_CURRENT_TIME;
+      gint64 before G_GNUC_UNUSED;
       gboolean waited = FALSE;
 
+      before = PANGO_TRACE_CURRENT_TIME;
+
       g_mutex_lock (&pats->mutex);
 
       while (!pats->match && !pats->fontset)
@@ -1050,9 +1056,11 @@ pango_fc_patterns_get_font_pattern (PangoFcPatterns *pats, int i, gboolean *prep
     }
   else
     {
-      gint64 before = PANGO_TRACE_CURRENT_TIME;
+      gint64 before G_GNUC_UNUSED;
       gboolean waited = FALSE;
 
+      before = PANGO_TRACE_CURRENT_TIME;
+
       g_mutex_lock (&pats->mutex);
 
       while (!pats->fontset)
@@ -1219,7 +1227,7 @@ pango_fc_fontset_finalize (GObject *object)
     {
       PangoCoverage *coverage = g_ptr_array_index (fontset->coverages, i);
       if (coverage)
-	pango_coverage_unref (coverage);
+	g_object_unref (coverage);
     }
   g_ptr_array_free (fontset->coverages, TRUE);
 
@@ -1354,7 +1362,9 @@ G_DEFINE_ABSTRACT_TYPE_WITH_CODE (PangoFcFontMap, pango_fc_font_map, PANGO_TYPE_
 static gpointer
 init_in_thread (gpointer task_data)
 {
-  gint64 before = PANGO_TRACE_CURRENT_TIME;
+  gint64 before G_GNUC_UNUSED;
+
+  before = PANGO_TRACE_CURRENT_TIME;
 
   FcInit ();
 
@@ -1388,9 +1398,11 @@ start_init_in_thread (PangoFcFontMap *fcfontmap)
 static void
 wait_for_fc_init (void)
 {
-  gint64 before = PANGO_TRACE_CURRENT_TIME;
+  gint64 before G_GNUC_UNUSED;
   gboolean waited = FALSE;
 
+  before = PANGO_TRACE_CURRENT_TIME;
+
   g_mutex_lock (&fc_init_mutex);
   while (fc_initialized < DEFAULT_CONFIG_INITIALIZED)
     {
@@ -2280,6 +2292,8 @@ pango_fc_font_map_cache_clear (PangoFcFontMap *fcfontmap)
   added = fcfontmap->priv->n_families;
 
   g_list_model_items_changed (G_LIST_MODEL (fcfontmap), 0, removed, added);
+  if (removed != added)
+    g_object_notify (G_OBJECT (fcfontmap), "n-items");
 
   pango_font_map_changed (PANGO_FONT_MAP (fcfontmap));
 }
@@ -2529,7 +2543,7 @@ _pango_fc_font_map_get_coverage (PangoFcFontMap *fcfontmap,
       data->coverage = _pango_fc_font_map_fc_to_coverage (charset);
     }
 
-  return pango_coverage_ref (data->coverage);
+  return g_object_ref (data->coverage);
 }
 
 /**
